#!/usr/bin/env python
# coding: utf-8

# In[ ]:


from setuptools import setup

setup(
    name='AbCluster',

    version='1.1.0',

    license='Apache License 2.0',

    author='BioSpace',
    
    author_email='biospaceinfo@gmail.com',

    url='https://www.biospace.info/',

    description='antibody sequence analysis including translation, numbering and clustering',

    keywords='antibody sequence translation numbering clustering',

    classifiers=[
        'Development Status :: 4 - Beta',
        'Natural Language :: Japanese',
        'Operating System :: POSIX :: Linux',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.7',
        'Topic :: Scientific/Engineering :: Bio-Informatics',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ],
)

